.. rst-class:: hidden
.. math::
    \newcommand{\dirac}[1]{\operatorname{\delta}\left(#1\right)}
    \newcommand{\e}[1]{\operatorname{e}^{#1}}
    \newcommand{\Hankel}[3]{\mathop{{}H_{#2}^{(#1)}}\!\left(#3\right)}
    \newcommand{\hankel}[3]{\mathop{{}h_{#2}^{(#1)}}\!\left(#3\right)}
    \newcommand{\i}{\mathrm{i}}
    \newcommand{\scalarprod}[2]{\left\langle#1,#2\right\rangle}
    \renewcommand{\vec}[1]{\mathbf{#1}}
    \newcommand{\wc}{\frac{\omega}{c}}
